codebuild_list_command_executions_for_sandbox: Gets a list of command executions for a sandbox

View source: R/codebuild_operations.R

codebuild_list_command_executions_for_sandboxR Documentation

Gets a list of command executions for a sandbox

Description

Gets a list of command executions for a sandbox.

See https://www.paws-r-sdk.com/docs/codebuild_list_command_executions_for_sandbox/ for full documentation.

Usage

codebuild_list_command_executions_for_sandbox(
  sandboxId,
  maxResults = NULL,
  sortOrder = NULL,
  nextToken = NULL
)

Arguments

sandboxId

[required] A sandboxId or sandboxArn.

maxResults

The maximum number of sandbox records to be retrieved.

sortOrder

The order in which sandbox records should be retrieved.

nextToken

The next token, if any, to get paginated results. You will get this value from previous execution of list sandboxes.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.