codebuild_list_sandboxes_for_project: Gets a list of sandboxes for a given project

View source: R/codebuild_operations.R

codebuild_list_sandboxes_for_projectR Documentation

Gets a list of sandboxes for a given project

Description

Gets a list of sandboxes for a given project.

See https://www.paws-r-sdk.com/docs/codebuild_list_sandboxes_for_project/ for full documentation.

Usage

codebuild_list_sandboxes_for_project(
  projectName,
  maxResults = NULL,
  sortOrder = NULL,
  nextToken = NULL
)

Arguments

projectName

[required] The CodeBuild project name.

maxResults

The maximum number of sandbox records to be retrieved.

sortOrder

The order in which sandbox records should be retrieved.

nextToken

The next token, if any, to get paginated results. You will get this value from previous execution of list sandboxes.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.