codebuild_update_project_visibility: Changes the public visibility for a project

View source: R/codebuild_operations.R

codebuild_update_project_visibilityR Documentation

Changes the public visibility for a project

Description

Changes the public visibility for a project. The project's build results, logs, and artifacts are available to the general public. For more information, see Public build projects in the CodeBuild User Guide.

See https://www.paws-r-sdk.com/docs/codebuild_update_project_visibility/ for full documentation.

Usage

codebuild_update_project_visibility(
  projectArn,
  projectVisibility,
  resourceAccessRole = NULL
)

Arguments

projectArn

[required] The Amazon Resource Name (ARN) of the build project.

projectVisibility

[required] Specifies the visibility of the project's builds. Possible values are:

PUBLIC_READ

The project builds are visible to the public.

PRIVATE

The project builds are not visible to the public.

resourceAccessRole

The ARN of the IAM role that enables CodeBuild to access the CloudWatch Logs and Amazon S3 artifacts for the project's builds.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.