View source: R/codebuild_operations.R
| codebuild_update_webhook | R Documentation |
Updates the webhook associated with an CodeBuild build project.
See https://www.paws-r-sdk.com/docs/codebuild_update_webhook/ for full documentation.
codebuild_update_webhook(
projectName,
branchFilter = NULL,
rotateSecret = NULL,
filterGroups = NULL,
buildType = NULL,
pullRequestBuildPolicy = NULL
)
projectName |
[required] The name of the CodeBuild project. |
branchFilter |
A regular expression used to determine which repository branches are built when a webhook is triggered. If the name of a branch matches the regular expression, then it is built. If It is recommended that you use |
rotateSecret |
A boolean value that specifies whether the associated GitHub repository's secret token should be updated. If you use Bitbucket for your repository, |
filterGroups |
An array of arrays of |
buildType |
Specifies the type of build this webhook will trigger.
|
pullRequestBuildPolicy |
A PullRequestBuildPolicy object that defines comment-based approval requirements for triggering builds on pull requests. This policy helps control when automated builds are executed based on contributor permissions and approval workflows. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.