View source: R/codegurusecurity_operations.R
| codegurusecurity_get_findings | R Documentation |
Returns a list of all findings generated by a particular scan.
See https://www.paws-r-sdk.com/docs/codegurusecurity_get_findings/ for full documentation.
codegurusecurity_get_findings(
scanName,
nextToken = NULL,
maxResults = NULL,
status = NULL
)
scanName |
[required] The name of the scan you want to retrieve findings from. |
nextToken |
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the |
maxResults |
The maximum number of results to return in the response. Use this parameter when paginating results. If additional results exist beyond the number you specify, the |
status |
The status of the findings you want to get. Pass either |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.