codegurusecurity_get_scan: Returns details about a scan, including whether or not a scan...

View source: R/codegurusecurity_operations.R

codegurusecurity_get_scanR Documentation

Returns details about a scan, including whether or not a scan has completed

Description

Returns details about a scan, including whether or not a scan has completed.

See https://www.paws-r-sdk.com/docs/codegurusecurity_get_scan/ for full documentation.

Usage

codegurusecurity_get_scan(scanName, runId = NULL)

Arguments

scanName

[required] The name of the scan you want to view details about.

runId

UUID that identifies the individual scan run you want to view details about. You retrieve this when you call the create_scan operation. Defaults to the latest scan run if missing.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.