View source: R/codegurusecurity_operations.R
| codegurusecurity_list_findings_metrics | R Documentation |
Returns metrics about all findings in an account within a specified time range.
See https://www.paws-r-sdk.com/docs/codegurusecurity_list_findings_metrics/ for full documentation.
codegurusecurity_list_findings_metrics(
nextToken = NULL,
maxResults = NULL,
startDate,
endDate
)
nextToken |
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the |
maxResults |
The maximum number of results to return in the response. Use this parameter when paginating results. If additional results exist beyond the number you specify, the |
startDate |
[required] The start date of the interval which you want to retrieve metrics from. Rounds to the nearest day. |
endDate |
[required] The end date of the interval which you want to retrieve metrics from. Round to the nearest day. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.