View source: R/codegurusecurity_operations.R
| codegurusecurity_list_scans | R Documentation |
Returns a list of all scans in an account. Does not return EXPRESS scans.
See https://www.paws-r-sdk.com/docs/codegurusecurity_list_scans/ for full documentation.
codegurusecurity_list_scans(nextToken = NULL, maxResults = NULL)
nextToken |
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request. For subsequent calls, use the |
maxResults |
The maximum number of results to return in the response. Use this parameter when paginating results. If additional results exist beyond the number you specify, the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.