View source: R/codepipeline_operations.R
| codepipeline_list_deploy_action_execution_targets | R Documentation |
Lists the targets for the deploy action.
See https://www.paws-r-sdk.com/docs/codepipeline_list_deploy_action_execution_targets/ for full documentation.
codepipeline_list_deploy_action_execution_targets(
pipelineName = NULL,
actionExecutionId,
filters = NULL,
maxResults = NULL,
nextToken = NULL
)
pipelineName |
The name of the pipeline with the deploy action. |
actionExecutionId |
[required] The execution ID for the deploy action. |
filters |
Filters the targets for a specified deploy action. |
maxResults |
The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned nextToken value. |
nextToken |
An identifier that was returned from the previous list action types call, which can be used to return the next set of action types in the list. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.