View source: R/codestarnotifications_operations.R
| codestarnotifications_delete_target | R Documentation |
Deletes a specified target for notifications.
See https://www.paws-r-sdk.com/docs/codestarnotifications_delete_target/ for full documentation.
codestarnotifications_delete_target(TargetAddress, ForceUnsubscribeAll = NULL)
TargetAddress |
[required] The Amazon Resource Name (ARN) of the Amazon Q Developer in chat applications topic or Amazon Q Developer in chat applications client to delete. |
ForceUnsubscribeAll |
A Boolean value that can be used to delete all associations with this Amazon Q Developer in chat applications topic. The default value is FALSE. If set to TRUE, all associations between that target and every notification rule in your Amazon Web Services account are deleted. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.