codestarnotifications_subscribe: Creates an association between a notification rule and an...

View source: R/codestarnotifications_operations.R

codestarnotifications_subscribeR Documentation

Creates an association between a notification rule and an Amazon Q Developer in chat applications topic or Amazon Q Developer in chat applications client so that the associated target can receive notifications when the events described in the rule are triggered

Description

Creates an association between a notification rule and an Amazon Q Developer in chat applications topic or Amazon Q Developer in chat applications client so that the associated target can receive notifications when the events described in the rule are triggered.

See https://www.paws-r-sdk.com/docs/codestarnotifications_subscribe/ for full documentation.

Usage

codestarnotifications_subscribe(Arn, Target, ClientRequestToken = NULL)

Arguments

Arn

[required] The Amazon Resource Name (ARN) of the notification rule for which you want to create the association.

Target

[required] Information about the Amazon Q Developer in chat applications topics or Amazon Q Developer in chat applications clients associated with a notification rule.

ClientRequestToken

An enumeration token that, when provided in a request, returns the next batch of the results.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.