codestarnotifications_unsubscribe: Removes an association between a notification rule and an...

View source: R/codestarnotifications_operations.R

codestarnotifications_unsubscribeR Documentation

Removes an association between a notification rule and an Amazon Q Developer in chat applications topic so that subscribers to that topic stop receiving notifications when the events described in the rule are triggered

Description

Removes an association between a notification rule and an Amazon Q Developer in chat applications topic so that subscribers to that topic stop receiving notifications when the events described in the rule are triggered.

See https://www.paws-r-sdk.com/docs/codestarnotifications_unsubscribe/ for full documentation.

Usage

codestarnotifications_unsubscribe(Arn, TargetAddress)

Arguments

Arn

[required] The Amazon Resource Name (ARN) of the notification rule.

TargetAddress

[required] The ARN of the Amazon Q Developer in chat applications topic to unsubscribe from the notification rule.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.