drs_associate_source_network_stack: Associate a Source Network to an existing CloudFormation...

View source: R/drs_operations.R

drs_associate_source_network_stackR Documentation

Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network

Description

Associate a Source Network to an existing CloudFormation Stack and modify launch templates to use this network. Can be used for reverting to previously deployed CloudFormation stacks.

See https://www.paws-r-sdk.com/docs/drs_associate_source_network_stack/ for full documentation.

Usage

drs_associate_source_network_stack(sourceNetworkID, cfnStackName)

Arguments

sourceNetworkID

[required] The Source Network ID to associate with CloudFormation template.

cfnStackName

[required] CloudFormation template to associate with a Source Network.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.