drs_create_launch_configuration_template: Creates a new Launch Configuration Template

View source: R/drs_operations.R

drs_create_launch_configuration_templateR Documentation

Creates a new Launch Configuration Template

Description

Creates a new Launch Configuration Template.

See https://www.paws-r-sdk.com/docs/drs_create_launch_configuration_template/ for full documentation.

Usage

drs_create_launch_configuration_template(
  tags = NULL,
  launchDisposition = NULL,
  targetInstanceTypeRightSizingMethod = NULL,
  copyPrivateIp = NULL,
  copyTags = NULL,
  licensing = NULL,
  exportBucketArn = NULL,
  postLaunchEnabled = NULL,
  launchIntoSourceInstance = NULL
)

Arguments

tags

Request to associate tags during creation of a Launch Configuration Template.

launchDisposition

Launch disposition.

targetInstanceTypeRightSizingMethod

Target instance type right-sizing method.

copyPrivateIp

Copy private IP.

copyTags

Copy tags.

licensing

Licensing.

exportBucketArn

S3 bucket ARN to export Source Network templates.

postLaunchEnabled

Whether we want to activate post-launch actions.

launchIntoSourceInstance

DRS will set the 'launch into instance ID' of any source server when performing a drill, recovery or failback to the previous region or availability zone, using the instance ID of the source instance.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.