drs_create_replication_configuration_template: Creates a new ReplicationConfigurationTemplate

View source: R/drs_operations.R

drs_create_replication_configuration_templateR Documentation

Creates a new ReplicationConfigurationTemplate

Description

Creates a new ReplicationConfigurationTemplate.

See https://www.paws-r-sdk.com/docs/drs_create_replication_configuration_template/ for full documentation.

Usage

drs_create_replication_configuration_template(
  stagingAreaSubnetId,
  associateDefaultSecurityGroup = NULL,
  replicationServersSecurityGroupsIDs,
  replicationServerInstanceType = NULL,
  useDedicatedReplicationServer = NULL,
  defaultLargeStagingDiskType = NULL,
  ebsEncryption,
  ebsEncryptionKeyArn = NULL,
  bandwidthThrottling,
  dataPlaneRouting = NULL,
  createPublicIP = NULL,
  stagingAreaTags,
  pitPolicy,
  tags = NULL,
  autoReplicateNewDisks = NULL,
  internetProtocol = NULL
)

Arguments

stagingAreaSubnetId

[required] The subnet to be used by the replication staging area.

associateDefaultSecurityGroup

Whether to associate the default Elastic Disaster Recovery Security group with the Replication Configuration Template.

replicationServersSecurityGroupsIDs

[required] The security group IDs that will be used by the replication server.

replicationServerInstanceType

The instance type to be used for the replication server.

useDedicatedReplicationServer

Whether to use a dedicated Replication Server in the replication staging area.

defaultLargeStagingDiskType

The Staging Disk EBS volume type to be used during replication.

ebsEncryption

[required] The type of EBS encryption to be used during replication.

ebsEncryptionKeyArn

The ARN of the EBS encryption key to be used during replication.

bandwidthThrottling

[required] Configure bandwidth throttling for the outbound data transfer rate of the Source Server in Mbps.

dataPlaneRouting

The data plane routing mechanism that will be used for replication.

createPublicIP

Whether to create a Public IP for the Recovery Instance by default.

stagingAreaTags

[required] A set of tags to be associated with all resources created in the replication staging area: EC2 replication server, EBS volumes, EBS snapshots, etc.

pitPolicy

[required] The Point in time (PIT) policy to manage snapshots taken during replication.

tags

A set of tags to be associated with the Replication Configuration Template resource.

autoReplicateNewDisks

Whether to allow the AWS replication agent to automatically replicate newly added disks.

internetProtocol

Which version of the Internet Protocol to use for replication of data. (IPv4 or IPv6)


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.