drs_list_extensible_source_servers: Returns a list of source servers on a staging account that...

View source: R/drs_operations.R

drs_list_extensible_source_serversR Documentation

Returns a list of source servers on a staging account that are extensible, which means that: a

Description

Returns a list of source servers on a staging account that are extensible, which means that: a. The source server is not already extended into this Account. b. The source server on the Account we’re reading from is not an extension of another source server.

See https://www.paws-r-sdk.com/docs/drs_list_extensible_source_servers/ for full documentation.

Usage

drs_list_extensible_source_servers(
  stagingAccountID,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

stagingAccountID

[required] The Id of the staging Account to retrieve extensible source servers from.

maxResults

The maximum number of extensible source servers to retrieve.

nextToken

The token of the next extensible source server to retrieve.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.