View source: R/drs_operations.R
| drs_put_launch_action | R Documentation |
Puts a resource launch action.
See https://www.paws-r-sdk.com/docs/drs_put_launch_action/ for full documentation.
drs_put_launch_action(
resourceId,
actionCode,
order,
actionId,
optional,
active,
name,
actionVersion,
category,
parameters = NULL,
description
)
resourceId |
[required] Launch configuration template Id or Source Server Id |
actionCode |
[required] Launch action code. |
order |
[required] Launch action order. |
actionId |
[required] Launch action Id. |
optional |
[required] Whether the launch will not be marked as failed if this action fails. |
active |
[required] Whether the launch action is active. |
name |
[required] Launch action name. |
actionVersion |
[required] Launch action version. |
category |
[required] Launch action category. |
parameters |
Launch action parameters. |
description |
[required] Launch action description. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.