drs_start_recovery: Launches Recovery Instances for the specified Source Servers

View source: R/drs_operations.R

drs_start_recoveryR Documentation

Launches Recovery Instances for the specified Source Servers

Description

Launches Recovery Instances for the specified Source Servers. For each Source Server you may choose a point in time snapshot to launch from, or use an on demand snapshot.

See https://www.paws-r-sdk.com/docs/drs_start_recovery/ for full documentation.

Usage

drs_start_recovery(sourceServers, isDrill = NULL, tags = NULL)

Arguments

sourceServers

[required] The Source Servers that we want to start a Recovery Job for.

isDrill

Whether this Source Server Recovery operation is a drill or not.

tags

The tags to be associated with the Recovery Job.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.