drs_update_failback_replication_configuration: Allows you to update the failback replication configuration...

View source: R/drs_operations.R

drs_update_failback_replication_configurationR Documentation

Allows you to update the failback replication configuration of a Recovery Instance by ID

Description

Allows you to update the failback replication configuration of a Recovery Instance by ID.

See https://www.paws-r-sdk.com/docs/drs_update_failback_replication_configuration/ for full documentation.

Usage

drs_update_failback_replication_configuration(
  recoveryInstanceID,
  name = NULL,
  bandwidthThrottling = NULL,
  usePrivateIP = NULL,
  internetProtocol = NULL
)

Arguments

recoveryInstanceID

[required] The ID of the Recovery Instance.

name

The name of the Failback Replication Configuration.

bandwidthThrottling

Configure bandwidth throttling for the outbound data transfer rate of the Recovery Instance in Mbps.

usePrivateIP

Whether to use Private IP for the failback replication of the Recovery Instance.

internetProtocol

Which version of the Internet Protocol to use for replication of data. (IPv4 or IPv6)


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.