drs_update_launch_configuration: Updates a LaunchConfiguration by Source Server ID

View source: R/drs_operations.R

drs_update_launch_configurationR Documentation

Updates a LaunchConfiguration by Source Server ID

Description

Updates a LaunchConfiguration by Source Server ID.

See https://www.paws-r-sdk.com/docs/drs_update_launch_configuration/ for full documentation.

Usage

drs_update_launch_configuration(
  sourceServerID,
  name = NULL,
  launchDisposition = NULL,
  targetInstanceTypeRightSizingMethod = NULL,
  copyPrivateIp = NULL,
  copyTags = NULL,
  licensing = NULL,
  postLaunchEnabled = NULL,
  launchIntoInstanceProperties = NULL
)

Arguments

sourceServerID

[required] The ID of the Source Server that we want to retrieve a Launch Configuration for.

name

The name of the launch configuration.

launchDisposition

The state of the Recovery Instance in EC2 after the recovery operation.

targetInstanceTypeRightSizingMethod

Whether Elastic Disaster Recovery should try to automatically choose the instance type that best matches the OS, CPU, and RAM of your Source Server.

copyPrivateIp

Whether we should copy the Private IP of the Source Server to the Recovery Instance.

copyTags

Whether we want to copy the tags of the Source Server to the EC2 machine of the Recovery Instance.

licensing

The licensing configuration to be used for this launch configuration.

postLaunchEnabled

Whether we want to enable post-launch actions for the Source Server.

launchIntoInstanceProperties

Launch into existing instance properties.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.