wellarchitected_associate_lenses: Associate a lens to a workload

View source: R/wellarchitected_operations.R

wellarchitected_associate_lensesR Documentation

Associate a lens to a workload

Description

Associate a lens to a workload.

See https://www.paws-r-sdk.com/docs/wellarchitected_associate_lenses/ for full documentation.

Usage

wellarchitected_associate_lenses(WorkloadId, LensAliases)

Arguments

WorkloadId

[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

LensAliases

[required] List of lens aliases to associate or disassociate with a workload. Up to 10 lenses can be specified.

Identify a lens using its LensSummary$LensAlias.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.