wellarchitected_create_lens_version: Create a new lens version

View source: R/wellarchitected_operations.R

wellarchitected_create_lens_versionR Documentation

Create a new lens version

Description

Create a new lens version.

See https://www.paws-r-sdk.com/docs/wellarchitected_create_lens_version/ for full documentation.

Usage

wellarchitected_create_lens_version(
  LensAlias,
  LensVersion,
  IsMajorVersion = NULL,
  ClientRequestToken
)

Arguments

LensAlias

[required] The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as ⁠arn:aws:wellarchitected:us-east-1::lens/serverless⁠. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as ⁠arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef⁠.

Each lens is identified by its LensSummary$LensAlias.

LensVersion

[required] The version of the lens being created.

IsMajorVersion

Set to true if this new major lens version.

ClientRequestToken

[required] A unique case-sensitive string used to ensure that this request is idempotent (executes only once).

You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned.

This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.