wellarchitected_create_milestone: Create a milestone for an existing workload

View source: R/wellarchitected_operations.R

wellarchitected_create_milestoneR Documentation

Create a milestone for an existing workload

Description

Create a milestone for an existing workload.

See https://www.paws-r-sdk.com/docs/wellarchitected_create_milestone/ for full documentation.

Usage

wellarchitected_create_milestone(WorkloadId, MilestoneName, ClientRequestToken)

Arguments

WorkloadId

[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

MilestoneName

[required] The name of the milestone in a workload.

Milestone names must be unique within a workload.

ClientRequestToken

[required] A unique case-sensitive string used to ensure that this request is idempotent (executes only once).

You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned.

This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.