wellarchitected_create_profile: Create a profile

View source: R/wellarchitected_operations.R

wellarchitected_create_profileR Documentation

Create a profile

Description

Create a profile.

See https://www.paws-r-sdk.com/docs/wellarchitected_create_profile/ for full documentation.

Usage

wellarchitected_create_profile(
  ProfileName,
  ProfileDescription,
  ProfileQuestions,
  ClientRequestToken,
  Tags = NULL
)

Arguments

ProfileName

[required] Name of the profile.

ProfileDescription

[required] The profile description.

ProfileQuestions

[required] The profile questions.

ClientRequestToken

[required] A unique case-sensitive string used to ensure that this request is idempotent (executes only once).

You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned.

This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail.

Tags

The tags assigned to the profile.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.