wellarchitected_create_template_share: Create a review template share

View source: R/wellarchitected_operations.R

wellarchitected_create_template_shareR Documentation

Create a review template share

Description

Create a review template share.

See https://www.paws-r-sdk.com/docs/wellarchitected_create_template_share/ for full documentation.

Usage

wellarchitected_create_template_share(
  TemplateArn,
  SharedWith,
  ClientRequestToken
)

Arguments

TemplateArn

[required] The review template ARN.

SharedWith

[required] The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload, lens, profile, or review template is shared.

ClientRequestToken

[required] A unique case-sensitive string used to ensure that this request is idempotent (executes only once).

You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned.

This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.