wellarchitected_create_workload: Create a new workload

View source: R/wellarchitected_operations.R

wellarchitected_create_workloadR Documentation

Create a new workload

Description

Create a new workload.

See https://www.paws-r-sdk.com/docs/wellarchitected_create_workload/ for full documentation.

Usage

wellarchitected_create_workload(
  WorkloadName,
  Description,
  Environment,
  AccountIds = NULL,
  AwsRegions = NULL,
  NonAwsRegions = NULL,
  PillarPriorities = NULL,
  ArchitecturalDesign = NULL,
  ReviewOwner = NULL,
  IndustryType = NULL,
  Industry = NULL,
  Lenses,
  Notes = NULL,
  ClientRequestToken,
  Tags = NULL,
  DiscoveryConfig = NULL,
  Applications = NULL,
  ProfileArns = NULL,
  ReviewTemplateArns = NULL,
  JiraConfiguration = NULL
)

Arguments

WorkloadName

[required] The name of the workload.

The name must be unique within an account within an Amazon Web Services Region. Spaces and capitalization are ignored when checking for uniqueness.

Description

[required] The description for the workload.

Environment

[required] The environment for the workload.

AccountIds

The list of Amazon Web Services account IDs associated with the workload.

AwsRegions

The list of Amazon Web Services Regions associated with the workload, for example, us-east-2, or ca-central-1.

NonAwsRegions

The list of non-Amazon Web Services Regions associated with the workload.

PillarPriorities

The priorities of the pillars, which are used to order items in the improvement plan. Each pillar is represented by its PillarReviewSummary$PillarId.

ArchitecturalDesign

The URL of the architectural design for the workload.

ReviewOwner

The review owner of the workload. The name, email address, or identifier for the primary group or individual that owns the workload review process.

IndustryType

The industry type for the workload.

If specified, must be one of the following:

  • Agriculture

  • Automobile

  • Defense

  • ⁠Design and Engineering⁠

  • ⁠Digital Advertising⁠

  • Education

  • ⁠Environmental Protection⁠

  • ⁠Financial Services⁠

  • Gaming

  • ⁠General Public Services⁠

  • Healthcare

  • Hospitality

  • InfoTech

  • ⁠Justice and Public Safety⁠

  • ⁠Life Sciences⁠

  • Manufacturing

  • Media & Entertainment

  • Mining & Resources

  • Oil & Gas

  • Power & Utilities

  • ⁠Professional Services⁠

  • ⁠Real Estate & Construction⁠

  • Retail & Wholesale

  • ⁠Social Protection⁠

  • Telecommunications

  • ⁠Travel, Transportation & Logistics⁠

  • Other

Industry

The industry for the workload.

Lenses

[required] The list of lenses associated with the workload. Each lens is identified by its LensSummary$LensAlias.

If a review template that specifies lenses is applied to the workload, those lenses are applied to the workload in addition to these lenses.

Notes

The notes associated with the workload.

For a review template, these are the notes that will be associated with the workload when the template is applied.

ClientRequestToken

[required] A unique case-sensitive string used to ensure that this request is idempotent (executes only once).

You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned.

This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail.

Tags

The tags to be associated with the workload.

DiscoveryConfig

Well-Architected discovery configuration settings associated to the workload.

Applications

List of AppRegistry application ARNs associated to the workload.

ProfileArns

The list of profile ARNs associated with the workload.

ReviewTemplateArns

The list of review template ARNs to associate with the workload.

JiraConfiguration

Jira configuration settings when creating a workload.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.