View source: R/wellarchitected_operations.R
| wellarchitected_create_workload_share | R Documentation |
Create a workload share.
See https://www.paws-r-sdk.com/docs/wellarchitected_create_workload_share/ for full documentation.
wellarchitected_create_workload_share(
WorkloadId,
SharedWith,
PermissionType,
ClientRequestToken
)
WorkloadId |
[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region. |
SharedWith |
[required] The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload, lens, profile, or review template is shared. |
PermissionType |
[required] Permission granted on a share request. |
ClientRequestToken |
[required] A unique case-sensitive string used to ensure that this request is idempotent (executes only once). You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned. This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.