wellarchitected_disassociate_lenses: Disassociate a lens from a workload

View source: R/wellarchitected_operations.R

wellarchitected_disassociate_lensesR Documentation

Disassociate a lens from a workload

Description

Disassociate a lens from a workload.

See https://www.paws-r-sdk.com/docs/wellarchitected_disassociate_lenses/ for full documentation.

Usage

wellarchitected_disassociate_lenses(WorkloadId, LensAliases)

Arguments

WorkloadId

[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

LensAliases

[required] List of lens aliases to associate or disassociate with a workload. Up to 10 lenses can be specified.

Identify a lens using its LensSummary$LensAlias.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.