wellarchitected_export_lens: Export an existing lens

View source: R/wellarchitected_operations.R

wellarchitected_export_lensR Documentation

Export an existing lens

Description

Export an existing lens.

See https://www.paws-r-sdk.com/docs/wellarchitected_export_lens/ for full documentation.

Usage

wellarchitected_export_lens(LensAlias, LensVersion = NULL)

Arguments

LensAlias

[required] The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as ⁠arn:aws:wellarchitected:us-east-1::lens/serverless⁠. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as ⁠arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef⁠.

Each lens is identified by its LensSummary$LensAlias.

LensVersion

The lens version to be exported.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.