wellarchitected_get_answer: Get the answer to a specific question in a workload review

View source: R/wellarchitected_operations.R

wellarchitected_get_answerR Documentation

Get the answer to a specific question in a workload review

Description

Get the answer to a specific question in a workload review.

See https://www.paws-r-sdk.com/docs/wellarchitected_get_answer/ for full documentation.

Usage

wellarchitected_get_answer(
  WorkloadId,
  LensAlias,
  QuestionId,
  MilestoneNumber = NULL
)

Arguments

WorkloadId

[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

LensAlias

[required] The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as ⁠arn:aws:wellarchitected:us-east-1::lens/serverless⁠. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as ⁠arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef⁠.

Each lens is identified by its LensSummary$LensAlias.

QuestionId

[required] The ID of the question.

MilestoneNumber

The milestone number.

A workload can have a maximum of 100 milestones.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.