View source: R/wellarchitected_operations.R
| wellarchitected_get_lens_version_difference | R Documentation |
Get lens version differences.
See https://www.paws-r-sdk.com/docs/wellarchitected_get_lens_version_difference/ for full documentation.
wellarchitected_get_lens_version_difference(
LensAlias,
BaseLensVersion = NULL,
TargetLensVersion = NULL
)
LensAlias |
[required] The alias of the lens. For Amazon Web Services official lenses, this is either the lens alias, such as For custom lenses, this is the lens ARN, such as Each lens is identified by its LensSummary$LensAlias. |
BaseLensVersion |
The base version of the lens. |
TargetLensVersion |
The lens version to target a difference for. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.