wellarchitected_list_check_details: List of Trusted Advisor check details by account related to...

View source: R/wellarchitected_operations.R

wellarchitected_list_check_detailsR Documentation

List of Trusted Advisor check details by account related to the workload

Description

List of Trusted Advisor check details by account related to the workload.

See https://www.paws-r-sdk.com/docs/wellarchitected_list_check_details/ for full documentation.

Usage

wellarchitected_list_check_details(
  WorkloadId,
  NextToken = NULL,
  MaxResults = NULL,
  LensArn,
  PillarId,
  QuestionId,
  ChoiceId
)

Arguments

WorkloadId

[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

NextToken

The token to use to retrieve the next set of results.

MaxResults

The maximum number of results to return for this request.

LensArn

[required] Well-Architected Lens ARN.

PillarId

[required] The ID used to identify a pillar, for example, security.

A pillar is identified by its PillarReviewSummary$PillarId.

QuestionId

[required] The ID of the question.

ChoiceId

[required] The ID of a choice.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.