wellarchitected_list_lens_review_improvements: List the improvements of a particular lens review

View source: R/wellarchitected_operations.R

wellarchitected_list_lens_review_improvementsR Documentation

List the improvements of a particular lens review

Description

List the improvements of a particular lens review.

See https://www.paws-r-sdk.com/docs/wellarchitected_list_lens_review_improvements/ for full documentation.

Usage

wellarchitected_list_lens_review_improvements(
  WorkloadId,
  LensAlias,
  PillarId = NULL,
  MilestoneNumber = NULL,
  NextToken = NULL,
  MaxResults = NULL,
  QuestionPriority = NULL
)

Arguments

WorkloadId

[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

LensAlias

[required] The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as ⁠arn:aws:wellarchitected:us-east-1::lens/serverless⁠. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as ⁠arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef⁠.

Each lens is identified by its LensSummary$LensAlias.

PillarId

The ID used to identify a pillar, for example, security.

A pillar is identified by its PillarReviewSummary$PillarId.

MilestoneNumber

The milestone number.

A workload can have a maximum of 100 milestones.

NextToken

The token to use to retrieve the next set of results.

MaxResults

The maximum number of results to return for this request.

QuestionPriority

The priority of the question.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.