View source: R/wellarchitected_operations.R
| wellarchitected_list_lens_shares | R Documentation |
List the lens shares associated with the lens.
See https://www.paws-r-sdk.com/docs/wellarchitected_list_lens_shares/ for full documentation.
wellarchitected_list_lens_shares(
LensAlias,
SharedWithPrefix = NULL,
NextToken = NULL,
MaxResults = NULL,
Status = NULL
)
LensAlias |
[required] The alias of the lens. For Amazon Web Services official lenses, this is either the lens alias, such as For custom lenses, this is the lens ARN, such as Each lens is identified by its LensSummary$LensAlias. |
SharedWithPrefix |
The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the lens is shared. |
NextToken |
The token to use to retrieve the next set of results. |
MaxResults |
The maximum number of results to return for this request. |
Status |
The status of the share request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.