wellarchitected_list_lenses: List the available lenses

View source: R/wellarchitected_operations.R

wellarchitected_list_lensesR Documentation

List the available lenses

Description

List the available lenses.

See https://www.paws-r-sdk.com/docs/wellarchitected_list_lenses/ for full documentation.

Usage

wellarchitected_list_lenses(
  NextToken = NULL,
  MaxResults = NULL,
  LensType = NULL,
  LensStatus = NULL,
  LensName = NULL
)

Arguments

NextToken

The token to use to retrieve the next set of results.

MaxResults

The maximum number of results to return for this request.

LensType

The type of lenses to be returned.

LensStatus

The status of lenses to be returned.

LensName

The full name of the lens.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.