wellarchitected_list_notifications: List lens notifications

View source: R/wellarchitected_operations.R

wellarchitected_list_notificationsR Documentation

List lens notifications

Description

List lens notifications.

See https://www.paws-r-sdk.com/docs/wellarchitected_list_notifications/ for full documentation.

Usage

wellarchitected_list_notifications(
  WorkloadId = NULL,
  NextToken = NULL,
  MaxResults = NULL,
  ResourceArn = NULL
)

Arguments

WorkloadId

The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

NextToken

The token to use to retrieve the next set of results.

MaxResults

The maximum number of results to return for this request.

ResourceArn

The ARN for the related resource for the notification.

Only one of WorkloadID or ResourceARN should be specified.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.