wellarchitected_list_profile_notifications: List profile notifications

View source: R/wellarchitected_operations.R

wellarchitected_list_profile_notificationsR Documentation

List profile notifications

Description

List profile notifications.

See https://www.paws-r-sdk.com/docs/wellarchitected_list_profile_notifications/ for full documentation.

Usage

wellarchitected_list_profile_notifications(
  WorkloadId = NULL,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

WorkloadId

The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

NextToken

The token to use to retrieve the next set of results.

MaxResults

The maximum number of results to return for this request.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.