wellarchitected_list_profiles: List profiles

View source: R/wellarchitected_operations.R

wellarchitected_list_profilesR Documentation

List profiles

Description

List profiles.

See https://www.paws-r-sdk.com/docs/wellarchitected_list_profiles/ for full documentation.

Usage

wellarchitected_list_profiles(
  ProfileNamePrefix = NULL,
  ProfileOwnerType = NULL,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

ProfileNamePrefix

An optional string added to the beginning of each profile name returned in the results.

ProfileOwnerType

Profile owner type.

NextToken

The token to use to retrieve the next set of results.

MaxResults

The maximum number of results to return for this request.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.