wellarchitected_list_review_template_answers: List the answers of a review template

View source: R/wellarchitected_operations.R

wellarchitected_list_review_template_answersR Documentation

List the answers of a review template

Description

List the answers of a review template.

See https://www.paws-r-sdk.com/docs/wellarchitected_list_review_template_answers/ for full documentation.

Usage

wellarchitected_list_review_template_answers(
  TemplateArn,
  LensAlias,
  PillarId = NULL,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

TemplateArn

[required] The ARN of the review template.

LensAlias

[required] The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as ⁠arn:aws:wellarchitected:us-east-1::lens/serverless⁠. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as ⁠arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef⁠.

Each lens is identified by its LensSummary$LensAlias.

PillarId

The ID used to identify a pillar, for example, security.

A pillar is identified by its PillarReviewSummary$PillarId.

NextToken

The token to use to retrieve the next set of results.

MaxResults

The maximum number of results to return for this request.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.