wellarchitected_list_review_templates: List review templates

View source: R/wellarchitected_operations.R

wellarchitected_list_review_templatesR Documentation

List review templates

Description

List review templates.

See https://www.paws-r-sdk.com/docs/wellarchitected_list_review_templates/ for full documentation.

Usage

wellarchitected_list_review_templates(NextToken = NULL, MaxResults = NULL)

Arguments

NextToken

The token to use to retrieve the next set of results.

MaxResults

The maximum number of results to return for this request.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.