wellarchitected_list_template_shares: List review template shares

View source: R/wellarchitected_operations.R

wellarchitected_list_template_sharesR Documentation

List review template shares

Description

List review template shares.

See https://www.paws-r-sdk.com/docs/wellarchitected_list_template_shares/ for full documentation.

Usage

wellarchitected_list_template_shares(
  TemplateArn,
  SharedWithPrefix = NULL,
  NextToken = NULL,
  MaxResults = NULL,
  Status = NULL
)

Arguments

TemplateArn

[required] The review template ARN.

SharedWithPrefix

The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the profile is shared.

NextToken

The token to use to retrieve the next set of results.

MaxResults

The maximum number of results to return for this request.

Status

The status of the share request.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.