wellarchitected_list_workload_shares: List the workload shares associated with the workload

View source: R/wellarchitected_operations.R

wellarchitected_list_workload_sharesR Documentation

List the workload shares associated with the workload

Description

List the workload shares associated with the workload.

See https://www.paws-r-sdk.com/docs/wellarchitected_list_workload_shares/ for full documentation.

Usage

wellarchitected_list_workload_shares(
  WorkloadId,
  SharedWithPrefix = NULL,
  NextToken = NULL,
  MaxResults = NULL,
  Status = NULL
)

Arguments

WorkloadId

[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

SharedWithPrefix

The Amazon Web Services account ID, organization ID, or organizational unit (OU) ID with which the workload is shared.

NextToken

The token to use to retrieve the next set of results.

MaxResults

The maximum number of results to return for this request.

Status

The status of the share request.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.