wellarchitected_update_answer: Update the answer to a specific question in a workload review

View source: R/wellarchitected_operations.R

wellarchitected_update_answerR Documentation

Update the answer to a specific question in a workload review

Description

Update the answer to a specific question in a workload review.

See https://www.paws-r-sdk.com/docs/wellarchitected_update_answer/ for full documentation.

Usage

wellarchitected_update_answer(
  WorkloadId,
  LensAlias,
  QuestionId,
  SelectedChoices = NULL,
  ChoiceUpdates = NULL,
  Notes = NULL,
  IsApplicable = NULL,
  Reason = NULL
)

Arguments

WorkloadId

[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

LensAlias

[required] The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as ⁠arn:aws:wellarchitected:us-east-1::lens/serverless⁠. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as ⁠arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef⁠.

Each lens is identified by its LensSummary$LensAlias.

QuestionId

[required] The ID of the question.

SelectedChoices

List of selected choice IDs in a question answer.

The values entered replace the previously selected choices.

ChoiceUpdates

A list of choices to update on a question in your workload. The String key corresponds to the choice ID to be updated.

Notes

The notes associated with the workload.

For a review template, these are the notes that will be associated with the workload when the template is applied.

IsApplicable

Defines whether this question is applicable to a lens review.

Reason

The reason why a question is not applicable to your workload.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.