wellarchitected_update_integration: Update integration features

View source: R/wellarchitected_operations.R

wellarchitected_update_integrationR Documentation

Update integration features

Description

Update integration features.

See https://www.paws-r-sdk.com/docs/wellarchitected_update_integration/ for full documentation.

Usage

wellarchitected_update_integration(
  WorkloadId,
  ClientRequestToken,
  IntegratingService
)

Arguments

WorkloadId

[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region.

ClientRequestToken

[required] A unique case-sensitive string used to ensure that this request is idempotent (executes only once).

You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned.

This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail.

IntegratingService

[required] Which integrated service to update.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.