wellarchitected_update_review_template_answer: Update a review template answer

View source: R/wellarchitected_operations.R

wellarchitected_update_review_template_answerR Documentation

Update a review template answer

Description

Update a review template answer.

See https://www.paws-r-sdk.com/docs/wellarchitected_update_review_template_answer/ for full documentation.

Usage

wellarchitected_update_review_template_answer(
  TemplateArn,
  LensAlias,
  QuestionId,
  SelectedChoices = NULL,
  ChoiceUpdates = NULL,
  Notes = NULL,
  IsApplicable = NULL,
  Reason = NULL
)

Arguments

TemplateArn

[required] The review template ARN.

LensAlias

[required] The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as ⁠arn:aws:wellarchitected:us-east-1::lens/serverless⁠. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as ⁠arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef⁠.

Each lens is identified by its LensSummary$LensAlias.

QuestionId

[required] The ID of the question.

SelectedChoices

List of selected choice IDs in a question answer.

The values entered replace the previously selected choices.

ChoiceUpdates

A list of choices to be updated.

Notes

The notes associated with the workload.

For a review template, these are the notes that will be associated with the workload when the template is applied.

IsApplicable

Defines whether this question is applicable to a lens review.

Reason

The update reason.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.