wellarchitected_update_review_template_lens_review: Update a lens review associated with a review template

View source: R/wellarchitected_operations.R

wellarchitected_update_review_template_lens_reviewR Documentation

Update a lens review associated with a review template

Description

Update a lens review associated with a review template.

See https://www.paws-r-sdk.com/docs/wellarchitected_update_review_template_lens_review/ for full documentation.

Usage

wellarchitected_update_review_template_lens_review(
  TemplateArn,
  LensAlias,
  LensNotes = NULL,
  PillarNotes = NULL
)

Arguments

TemplateArn

[required] The review template ARN.

LensAlias

[required] The alias of the lens.

For Amazon Web Services official lenses, this is either the lens alias, such as serverless, or the lens ARN, such as ⁠arn:aws:wellarchitected:us-east-1::lens/serverless⁠. Note that some operations (such as ExportLens and CreateLensShare) are not permitted on Amazon Web Services official lenses.

For custom lenses, this is the lens ARN, such as ⁠arn:aws:wellarchitected:us-west-2:123456789012:lens/0123456789abcdef01234567890abcdef⁠.

Each lens is identified by its LensSummary$LensAlias.

LensNotes

The notes associated with the workload.

For a review template, these are the notes that will be associated with the workload when the template is applied.

PillarNotes

List of pillar notes of a lens review in a workload.

For a review template, these are the notes that will be associated with the workload when the template is applied.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.