xray_start_trace_retrieval: Initiates a trace retrieval process using the specified time...

View source: R/xray_operations.R

xray_start_trace_retrievalR Documentation

Initiates a trace retrieval process using the specified time range and for the given trace IDs in the Transaction Search generated CloudWatch log group

Description

Initiates a trace retrieval process using the specified time range and for the given trace IDs in the Transaction Search generated CloudWatch log group. For more information, see Transaction Search.

See https://www.paws-r-sdk.com/docs/xray_start_trace_retrieval/ for full documentation.

Usage

xray_start_trace_retrieval(TraceIds, StartTime, EndTime)

Arguments

TraceIds

[required] Specify the trace IDs of the traces to be retrieved.

StartTime

[required] The start of the time range to retrieve traces. The range is inclusive, so the specified start time is included in the query. Specified as epoch time, the number of seconds since January 1, 1970, 00:00:00 UTC.

EndTime

[required] The end of the time range to retrieve traces. The range is inclusive, so the specified end time is included in the query. Specified as epoch time, the number of seconds since January 1, 1970, 00:00:00 UTC.


paws.developer.tools documentation built on May 30, 2026, 9:06 a.m.