View source: R/codegurusecurity_operations.R
| codegurusecurity_get_scan | R Documentation |
Returns details about a scan, including whether or not a scan has completed.
See https://www.paws-r-sdk.com/docs/codegurusecurity_get_scan/ for full documentation.
codegurusecurity_get_scan(scanName, runId = NULL)
scanName |
[required] The name of the scan you want to view details about. |
runId |
UUID that identifies the individual scan run you want to view details about. You retrieve this when you call the |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.