View source: R/codestarnotifications_operations.R
| codestarnotifications_subscribe | R Documentation |
Creates an association between a notification rule and an Amazon Q Developer in chat applications topic or Amazon Q Developer in chat applications client so that the associated target can receive notifications when the events described in the rule are triggered.
See https://www.paws-r-sdk.com/docs/codestarnotifications_subscribe/ for full documentation.
codestarnotifications_subscribe(Arn, Target, ClientRequestToken = NULL)
Arn |
[required] The Amazon Resource Name (ARN) of the notification rule for which you want to create the association. |
Target |
[required] Information about the Amazon Q Developer in chat applications topics or Amazon Q Developer in chat applications clients associated with a notification rule. |
ClientRequestToken |
An enumeration token that, when provided in a request, returns the next batch of the results. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.