View source: R/drs_operations.R
| drs_update_failback_replication_configuration | R Documentation |
Allows you to update the failback replication configuration of a Recovery Instance by ID.
See https://www.paws-r-sdk.com/docs/drs_update_failback_replication_configuration/ for full documentation.
drs_update_failback_replication_configuration(
recoveryInstanceID,
name = NULL,
bandwidthThrottling = NULL,
usePrivateIP = NULL,
internetProtocol = NULL
)
recoveryInstanceID |
[required] The ID of the Recovery Instance. |
name |
The name of the Failback Replication Configuration. |
bandwidthThrottling |
Configure bandwidth throttling for the outbound data transfer rate of the Recovery Instance in Mbps. |
usePrivateIP |
Whether to use Private IP for the failback replication of the Recovery Instance. |
internetProtocol |
Which version of the Internet Protocol to use for replication of data. (IPv4 or IPv6) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.