View source: R/wellarchitected_operations.R
| wellarchitected_associate_lenses | R Documentation |
Associate a lens to a workload.
See https://www.paws-r-sdk.com/docs/wellarchitected_associate_lenses/ for full documentation.
wellarchitected_associate_lenses(WorkloadId, LensAliases)
WorkloadId |
[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region. |
LensAliases |
[required] List of lens aliases to associate or disassociate with a workload. Up to 10 lenses can be specified. Identify a lens using its LensSummary$LensAlias. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.