View source: R/wellarchitected_operations.R
| wellarchitected_create_lens_version | R Documentation |
Create a new lens version.
See https://www.paws-r-sdk.com/docs/wellarchitected_create_lens_version/ for full documentation.
wellarchitected_create_lens_version(
LensAlias,
LensVersion,
IsMajorVersion = NULL,
ClientRequestToken
)
LensAlias |
[required] The alias of the lens. For Amazon Web Services official lenses, this is either the lens alias, such as For custom lenses, this is the lens ARN, such as Each lens is identified by its LensSummary$LensAlias. |
LensVersion |
[required] The version of the lens being created. |
IsMajorVersion |
Set to true if this new major lens version. |
ClientRequestToken |
[required] A unique case-sensitive string used to ensure that this request is idempotent (executes only once). You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned. This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.