View source: R/wellarchitected_operations.R
| wellarchitected_create_review_template | R Documentation |
Create a review template.
See https://www.paws-r-sdk.com/docs/wellarchitected_create_review_template/ for full documentation.
wellarchitected_create_review_template(
TemplateName,
Description,
Lenses,
Notes = NULL,
Tags = NULL,
ClientRequestToken
)
TemplateName |
[required] Name of the review template. |
Description |
[required] The review template description. |
Lenses |
[required] Lenses applied to the review template. |
Notes |
The notes associated with the workload. For a review template, these are the notes that will be associated with the workload when the template is applied. |
Tags |
The tags assigned to the review template. |
ClientRequestToken |
[required] A unique case-sensitive string used to ensure that this request is idempotent (executes only once). You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after the original request has completed successfully, the result of the original request is returned. This token is listed as required, however, if you do not specify it, the Amazon Web Services SDKs automatically generate one for you. If you are not using the Amazon Web Services SDK or the CLI, you must provide this token or the request will fail. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.