View source: R/wellarchitected_operations.R
| wellarchitected_export_lens | R Documentation |
Export an existing lens.
See https://www.paws-r-sdk.com/docs/wellarchitected_export_lens/ for full documentation.
wellarchitected_export_lens(LensAlias, LensVersion = NULL)
LensAlias |
[required] The alias of the lens. For Amazon Web Services official lenses, this is either the lens alias, such as For custom lenses, this is the lens ARN, such as Each lens is identified by its LensSummary$LensAlias. |
LensVersion |
The lens version to be exported. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.