View source: R/wellarchitected_operations.R
| wellarchitected_get_answer | R Documentation |
Get the answer to a specific question in a workload review.
See https://www.paws-r-sdk.com/docs/wellarchitected_get_answer/ for full documentation.
wellarchitected_get_answer(
WorkloadId,
LensAlias,
QuestionId,
MilestoneNumber = NULL
)
WorkloadId |
[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region. |
LensAlias |
[required] The alias of the lens. For Amazon Web Services official lenses, this is either the lens alias, such as For custom lenses, this is the lens ARN, such as Each lens is identified by its LensSummary$LensAlias. |
QuestionId |
[required] The ID of the question. |
MilestoneNumber |
The milestone number. A workload can have a maximum of 100 milestones. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.