View source: R/wellarchitected_operations.R
| wellarchitected_get_review_template_answer | R Documentation |
Get review template answer.
See https://www.paws-r-sdk.com/docs/wellarchitected_get_review_template_answer/ for full documentation.
wellarchitected_get_review_template_answer(TemplateArn, LensAlias, QuestionId)
TemplateArn |
[required] The review template ARN. |
LensAlias |
[required] The alias of the lens. For Amazon Web Services official lenses, this is either the lens alias, such as For custom lenses, this is the lens ARN, such as Each lens is identified by its LensSummary$LensAlias. |
QuestionId |
[required] The ID of the question. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.