View source: R/wellarchitected_operations.R
| wellarchitected_list_check_details | R Documentation |
List of Trusted Advisor check details by account related to the workload.
See https://www.paws-r-sdk.com/docs/wellarchitected_list_check_details/ for full documentation.
wellarchitected_list_check_details(
WorkloadId,
NextToken = NULL,
MaxResults = NULL,
LensArn,
PillarId,
QuestionId,
ChoiceId
)
WorkloadId |
[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region. |
NextToken |
The token to use to retrieve the next set of results. |
MaxResults |
The maximum number of results to return for this request. |
LensArn |
[required] Well-Architected Lens ARN. |
PillarId |
[required] The ID used to identify a pillar, for example, A pillar is identified by its PillarReviewSummary$PillarId. |
QuestionId |
[required] The ID of the question. |
ChoiceId |
[required] The ID of a choice. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.