View source: R/wellarchitected_operations.R
| wellarchitected_list_profile_notifications | R Documentation |
List profile notifications.
See https://www.paws-r-sdk.com/docs/wellarchitected_list_profile_notifications/ for full documentation.
wellarchitected_list_profile_notifications(
WorkloadId = NULL,
NextToken = NULL,
MaxResults = NULL
)
WorkloadId |
The ID assigned to the workload. This ID is unique within an Amazon Web Services Region. |
NextToken |
The token to use to retrieve the next set of results. |
MaxResults |
The maximum number of results to return for this request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.