View source: R/wellarchitected_operations.R
| wellarchitected_list_review_template_answers | R Documentation |
List the answers of a review template.
See https://www.paws-r-sdk.com/docs/wellarchitected_list_review_template_answers/ for full documentation.
wellarchitected_list_review_template_answers(
TemplateArn,
LensAlias,
PillarId = NULL,
NextToken = NULL,
MaxResults = NULL
)
TemplateArn |
[required] The ARN of the review template. |
LensAlias |
[required] The alias of the lens. For Amazon Web Services official lenses, this is either the lens alias, such as For custom lenses, this is the lens ARN, such as Each lens is identified by its LensSummary$LensAlias. |
PillarId |
The ID used to identify a pillar, for example, A pillar is identified by its PillarReviewSummary$PillarId. |
NextToken |
The token to use to retrieve the next set of results. |
MaxResults |
The maximum number of results to return for this request. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.