View source: R/wellarchitected_operations.R
| wellarchitected_update_lens_review | R Documentation |
Update lens review for a particular workload.
See https://www.paws-r-sdk.com/docs/wellarchitected_update_lens_review/ for full documentation.
wellarchitected_update_lens_review(
WorkloadId,
LensAlias,
LensNotes = NULL,
PillarNotes = NULL,
JiraConfiguration = NULL
)
WorkloadId |
[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region. |
LensAlias |
[required] The alias of the lens. For Amazon Web Services official lenses, this is either the lens alias, such as For custom lenses, this is the lens ARN, such as Each lens is identified by its LensSummary$LensAlias. |
LensNotes |
The notes associated with the workload. For a review template, these are the notes that will be associated with the workload when the template is applied. |
PillarNotes |
List of pillar notes of a lens review in a workload. For a review template, these are the notes that will be associated with the workload when the template is applied. |
JiraConfiguration |
Configuration of the Jira integration. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.