View source: R/wellarchitected_operations.R
| wellarchitected_update_review_template_answer | R Documentation |
Update a review template answer.
See https://www.paws-r-sdk.com/docs/wellarchitected_update_review_template_answer/ for full documentation.
wellarchitected_update_review_template_answer(
TemplateArn,
LensAlias,
QuestionId,
SelectedChoices = NULL,
ChoiceUpdates = NULL,
Notes = NULL,
IsApplicable = NULL,
Reason = NULL
)
TemplateArn |
[required] The review template ARN. |
LensAlias |
[required] The alias of the lens. For Amazon Web Services official lenses, this is either the lens alias, such as For custom lenses, this is the lens ARN, such as Each lens is identified by its LensSummary$LensAlias. |
QuestionId |
[required] The ID of the question. |
SelectedChoices |
List of selected choice IDs in a question answer. The values entered replace the previously selected choices. |
ChoiceUpdates |
A list of choices to be updated. |
Notes |
The notes associated with the workload. For a review template, these are the notes that will be associated with the workload when the template is applied. |
IsApplicable |
Defines whether this question is applicable to a lens review. |
Reason |
The update reason. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.