View source: R/wellarchitected_operations.R
| wellarchitected_update_review_template_lens_review | R Documentation |
Update a lens review associated with a review template.
See https://www.paws-r-sdk.com/docs/wellarchitected_update_review_template_lens_review/ for full documentation.
wellarchitected_update_review_template_lens_review(
TemplateArn,
LensAlias,
LensNotes = NULL,
PillarNotes = NULL
)
TemplateArn |
[required] The review template ARN. |
LensAlias |
[required] The alias of the lens. For Amazon Web Services official lenses, this is either the lens alias, such as For custom lenses, this is the lens ARN, such as Each lens is identified by its LensSummary$LensAlias. |
LensNotes |
The notes associated with the workload. For a review template, these are the notes that will be associated with the workload when the template is applied. |
PillarNotes |
List of pillar notes of a lens review in a workload. For a review template, these are the notes that will be associated with the workload when the template is applied. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.