View source: R/wellarchitected_operations.R
| wellarchitected_update_workload | R Documentation |
Update an existing workload.
See https://www.paws-r-sdk.com/docs/wellarchitected_update_workload/ for full documentation.
wellarchitected_update_workload(
WorkloadId,
WorkloadName = NULL,
Description = NULL,
Environment = NULL,
AccountIds = NULL,
AwsRegions = NULL,
NonAwsRegions = NULL,
PillarPriorities = NULL,
ArchitecturalDesign = NULL,
ReviewOwner = NULL,
IsReviewOwnerUpdateAcknowledged = NULL,
IndustryType = NULL,
Industry = NULL,
Notes = NULL,
ImprovementStatus = NULL,
DiscoveryConfig = NULL,
Applications = NULL,
JiraConfiguration = NULL
)
WorkloadId |
[required] The ID assigned to the workload. This ID is unique within an Amazon Web Services Region. |
WorkloadName |
The name of the workload. The name must be unique within an account within an Amazon Web Services Region. Spaces and capitalization are ignored when checking for uniqueness. |
Description |
The description for the workload. |
Environment |
The environment for the workload. |
AccountIds |
The list of Amazon Web Services account IDs associated with the workload. |
AwsRegions |
The list of Amazon Web Services Regions associated with the workload, for example, |
NonAwsRegions |
The list of non-Amazon Web Services Regions associated with the workload. |
PillarPriorities |
The priorities of the pillars, which are used to order items in the improvement plan. Each pillar is represented by its PillarReviewSummary$PillarId. |
ArchitecturalDesign |
The URL of the architectural design for the workload. |
ReviewOwner |
The review owner of the workload. The name, email address, or identifier for the primary group or individual that owns the workload review process. |
IsReviewOwnerUpdateAcknowledged |
Flag indicating whether the workload owner has acknowledged that the Review owner field is required. If a Review owner is not added to the workload within 60 days of acknowledgement, access to the workload is restricted until an owner is added. |
IndustryType |
The industry type for the workload. If specified, must be one of the following:
|
Industry |
The industry for the workload. |
Notes |
The notes associated with the workload. For a review template, these are the notes that will be associated with the workload when the template is applied. |
ImprovementStatus |
The improvement status for a workload. |
DiscoveryConfig |
Well-Architected discovery configuration settings to associate to the workload. |
Applications |
List of AppRegistry application ARNs to associate to the workload. |
JiraConfiguration |
Configuration of the Jira integration. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.